@@ -3,7 +3,7 @@ package Finance::CoinbasePro::API::CLI::Util::CurrencyUtil
 
 use strict;
 use warnings;
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use base qw(Exporter);
 our @EXPORT_OK = qw( get_product_currencies
@@ -148,11 +148,12 @@ sub _log10 { my $n = shift; return 2 unless $n; return log($n) / log(10); }
 1;
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI::Util::CurrencyUtil
+Finance::CoinbasePro::API::CLI::Util::CurrencyUtil - Finance::CoinbasePro::API::CLI::Util::CurrencyUtil
 
 
 =head1 DESCRIPTION
